pub struct LocalizedConfig {
    pub config: Config,
    pub workspace: PathBuf,
}

Fields

config: Configworkspace: PathBuf

The directory containing ./.cargo/config.toml

Implementations

Search for and open .cargo/config.toml in any parent of the workspace root path.

Read an environment variable from the [env] section in this .cargo/config.toml.

It is interpreted as path and canonicalized relative to Self::workspace if EnvOption::Value::relative is set.

Process environment variables (from std::env::var()) have precedence unless EnvOption::Value::force is set. This value is also returned if the given key was not set under [env].