Struct cargo_subcommand::LocalizedConfig
source · [−]pub struct LocalizedConfig {
pub config: Config,
pub workspace: PathBuf,
}Fields
config: Configworkspace: PathBufThe directory containing ./.cargo/config.toml
Implementations
sourceimpl LocalizedConfig
impl LocalizedConfig
pub fn new(workspace: PathBuf) -> Result<Self, Error>
sourcepub fn find_cargo_config_for_workspace(
workspace: impl AsRef<Path>
) -> Result<Option<Self>, Error>
pub fn find_cargo_config_for_workspace(
workspace: impl AsRef<Path>
) -> Result<Option<Self>, Error>
Search for and open .cargo/config.toml in any parent of the workspace root path.
sourcepub fn resolve_env(&self, key: &str) -> Result<Cow<'_, str>, EnvError>
pub fn resolve_env(&self, key: &str) -> Result<Cow<'_, str>, EnvError>
Read an environment variable from the [env] section in this .cargo/config.toml.
It is interpreted as path and canonicalized relative to Self::workspace if
EnvOption::Value::relative is set.
Process environment variables (from std::env::var()) have precedence
unless EnvOption::Value::force is set. This value is also returned if
the given key was not set under [env].